@@ -11,7 +11,7 @@ if (is.null(plugin))
 	d <- length(x)
    x <- matrix(x, 1, d)
    
-   predx <- predict.km(object=model, newdata=x, type=type)
+   predx <- predict(object=model, newdata=x, type=type, checkNames = FALSE)
    kriging.mean <- predx$mean
    kriging.sd <- predx$sd
 	
