@@ -6,7 +6,7 @@ newdata <- matrix(x, 1, d)
 ######### Compute q.min if missing #########
 if (is.null(q.min))
 {
-  pred <- predict.km(model, newdata=model@X, type=type)
+  pred <- predict.km(model, newdata=model@X, type=type, checkNames = FALSE)
   mk <- pred$mean
   sk <- pred$sd
   sk <- sk*sqrt(model@n/(model@n-1))
